@@ -1,14 +1,14 @@
 context("scaleSpeciesvalues")
 
 test_that("scaleSpeciesvalues: use",{
-  skip_on_cran()
+ # skip_on_cran()
   x <- generate.Artificial.Data(n_species = 3, n_traits = 2, n_communities = 3,
                                 occurence_distribution = 1,
                                 average_richness = 1,
                                 sd_richness = 1,
                                 mechanism_random = FALSE)
 
-  traitmatrix <- x$traits;
+  traitmatrix <- x$traits
   traitmatrix$trait1 <- c(1,2,3)
   traitmatrix$trait2 <- c(2,3,4)
 
@@ -26,7 +26,7 @@ test_that("scaleSpeciesvalues: use",{
 })
 
 test_that("scaleSpeciesvaluess: abuse", {
-  skip_on_cran()
+  #skip_on_cran()
   x1 <- c(1,2,3)
   x2 <- c(2,3,4)
   traitmatrix <- cbind(x1,x2)
@@ -42,7 +42,7 @@ test_that("scaleSpeciesvaluess: abuse", {
                                 sd_richness = 1,
                                 mechanism_random = FALSE)
 
-  traitmatrix <- x$traits;
+  traitmatrix <- x$traits
   traitmatrix$trait1 <- c(1,1,2)
   traitmatrix$trait2 <- c(2,2,2)
   expect_error(
